function [finds sinds] = feature_order_index(prms)
%
% Index of feature order
%
% [finds sinds] = feature_order_index(prms)
%
% Input:
%  prms - Parameters for glac/glac_on_grid [struct]
%
% Output:
%  finds - Feature order indexes, 0th or 1st, [dim x 1]
%  sinds - Position index in spatial bins     [dim x 1]
%

if isfield(prms, 'nsbins')
	%- GLAC on grid -%
	nsbin = prod(prms.nsbins);
	finds = cat(1, zeros(prms.nbin*nsbin,1), ones(size(prms.rvecs,1)*prms.nbin^2*nsbin,1) );
	sinds = cat(1, reshape( repmat(1:nsbin, prms.nbin,1) ,[],1),  repmat(reshape( repmat(1:nsbin, prms.nbin^2,1) ,[],1),size(prms.rvecs,1),1) );
else
	%- GLAC -%
	finds = cat(1, zeros(prms.nbin,1), ones(size(prms.rvecs,1)*prms.nbin^2,1) );
	sinds = ones(size(finds));
end
